==> lifestyle-pimcore-sylius-1.0.1-493bb3.zip: tests/Lifestyle/Pimcore/SyliusBundle/Export/Product/Version1/Update/MapperTest.php <==
<?php

/**
 * Class MapperTest
 *
 * LICENSE: This Software is the property of Lifestyle Webconsulting GmbH (Aschaffenburg, Germany)
 * and is protected by copyright law - it is NOT Freeware.
 *
 * Any unauthorized use of this software without a valid license
 * is a violation of the license agreement and will be prosecuted by
 * civil and criminal law.
 *
 * @copyright  2017 Lifestyle Webconsulting GmbH
 * @link       http://www.life-style.de
 */

namespace Tests\Lifestyle\Pimcore\SyliusBundle\Export\Product\Version1\Update;

use JMS\Serializer\SerializerBuilder;
use Lifestyle\Pimcore\ExportBundle\Mapping\DataCollector\DataCollector;
use Lifestyle\Pimcore\ExportBundle\Mapping\DataCollector\DataCollectorInterface;
use Lifestyle\Pimcore\SyliusBundle\Export\Product\Version1\Update\Mapper;
use PHPUnit\Framework\TestCase;

/**
 * Class MapperTest
 * @package Tests\Lifestyle\Pimcore\SyliusBundle\Export\Product\Version1\Update
 */
class MapperTest extends TestCase
{
    public function testMapping()
    {
        $collector = $this->prepareDataCollector();

        $mapper = new Mapper();
        $requestModel = $mapper->mapRequestModel($collector);

        $this->assertSame('123456', $requestModel->getCode());
        $this->assertSame('testMainTaxon', $requestModel->getMainTaxon());
        $this->assertSame(['unit_TEST'], $requestModel->getChannels());
        $this->assertTrue($requestModel->isEnabled());

        $this->assertCount(2, $requestModel->getTranslations());

        $this->assertSame('English Name', $requestModel->getTranslations()['en_US']->getName());
        $this->assertSame('English Description', $requestModel->getTranslations()['en_US']->getDescription());
        $this->assertSame('English Short Description', $requestModel->getTranslations()['en_US']->getShortDescription());
        $this->assertSame('English Slug', $requestModel->getTranslations()['en_US']->getSlug());
        $this->assertSame('English Meta Description', $requestModel->getTranslations()['en_US']->getMetaDescription());
        $this->assertSame('English Meta Keywords', $requestModel->getTranslations()['en_US']->getMetaKeywords());
        $this->assertSame('en_US', $requestModel->getTranslations()['en_US']->getLocale());

        $this->assertSame('German Name', $requestModel->getTranslations()['de_DE']->getName());
        $this->assertSame('German Description', $requestModel->getTranslations()['de_DE']->getDescription());
        $this->assertSame('German Short Description', $requestModel->getTranslations()['de_DE']->getShortDescription());
        $this->assertSame('German Slug', $requestModel->getTranslations()['de_DE']->getSlug());
        $this->assertSame('German Meta Description', $requestModel->getTranslations()['de_DE']->getMetaDescription());
        $this->assertSame('German Meta Keywords', $requestModel->getTranslations()['de_DE']->getMetaKeywords());
        $this->assertSame('de_DE', $requestModel->getTranslations()['de_DE']->getLocale());
    }

    public function testSerialization()
    {
        $collector = $this->prepareDataCollector();

        $mapper = new Mapper();
        $requestModel = $mapper->mapRequestModel($collector);

        $serializer = SerializerBuilder::create()->build();
        $json = $serializer->serialize($requestModel, 'json');

        $this->assertSame(
            '{"code":"123456","enabled":true,"mainTaxon":"testMainTaxon","channels":["unit_TEST"],"translations":{"en_US":{"name":"English Name","slug":"English Slug","description":"English Description","shortDescription":"English Short Description","metaKeywords":"English Meta Keywords","metaDescription":"English Meta Description"},"de_DE":{"name":"German Name","slug":"German Slug","description":"German Description","shortDescription":"German Short Description","metaKeywords":"German Meta Keywords","metaDescription":"German Meta Description"}}}',
            $json
        );
    }

    /**
     * @return DataCollectorInterface
     */
    private function prepareDataCollector()
    {
        // Add base attributes
        $collector = new DataCollector();
        $collector->addItem('id', '123456');
        $collector->addItem('mainTaxon', 'testMainTaxon');
        $collector->addItem('channels', ['unit_TEST']);

        // Add translated fields
        $collector->addItem('name', 'English Name', 'en_US');
        $collector->addItem('name', 'German Name', 'de_DE');

        $collector->addItem('description', 'English Description', 'en_US');
        $collector->addItem('description', 'German Description', 'de_DE');

        $collector->addItem('shortDescription', 'English Short Description', 'en_US');
        $collector->addItem('shortDescription', 'German Short Description', 'de_DE');

        $collector->addItem('slug', 'English Slug', 'en_US');
        $collector->addItem('slug', 'German Slug', 'de_DE');

        $collector->addItem('metaKeywords', 'English Meta Keywords', 'en_US');
        $collector->addItem('metaKeywords', 'German Meta Keywords', 'de_DE');

        $collector->addItem('metaDescription', 'English Meta Description', 'en_US');
        $collector->addItem('metaDescription', 'German Meta Description', 'de_DE');

        return $collector;
    }
}

==> lifestyle-pimcore-sylius-1.0.2-986783.zip: tests/Lifestyle/Pimcore/SyliusBundle/Export/Product/Version1/Update/MapperTest.php <==
<?php

/**
 * Class MapperTest
 *
 * LICENSE: This Software is the property of Lifestyle Webconsulting GmbH (Aschaffenburg, Germany)
 * and is protected by copyright law - it is NOT Freeware.
 *
 * Any unauthorized use of this software without a valid license
 * is a violation of the license agreement and will be prosecuted by
 * civil and criminal law.
 *
 * @copyright  2017 Lifestyle Webconsulting GmbH
 * @link       http://www.life-style.de
 */

namespace Tests\Lifestyle\Pimcore\SyliusBundle\Export\Product\Version1\Update;

use JMS\Serializer\SerializerBuilder;
use Lifestyle\Pimcore\ExportBundle\Mapping\DataCollector\DataCollector;
use Lifestyle\Pimcore\ExportBundle\Mapping\DataCollector\DataCollectorInterface;
use Lifestyle\Pimcore\SyliusBundle\Export\Product\Version1\Update\Mapper;
use PHPUnit\Framework\TestCase;

/**
 * Class MapperTest
 * @package Tests\Lifestyle\Pimcore\SyliusBundle\Export\Product\Version1\Update
 */
class MapperTest extends TestCase
{
    public function testMapping()
    {
        $collector = $this->prepareDataCollector();

        $mapper = new Mapper();
        $requestModel = $mapper->mapRequestModel($collector);

        $this->assertSame('123456', $requestModel->getCode());
        $this->assertSame('testMainTaxon', $requestModel->getMainTaxon());
        $this->assertSame(['unit_TEST'], $requestModel->getChannels());
        $this->assertTrue($requestModel->isEnabled());

        $this->assertCount(2, $requestModel->getTranslations());

        $this->assertSame('English Name', $requestModel->getTranslations()['en_US']->getName());
        $this->assertSame('English Description', $requestModel->getTranslations()['en_US']->getDescription());
        $this->assertSame('English Short Description', $requestModel->getTranslations()['en_US']->getShortDescription());
        $this->assertSame('English Slug', $requestModel->getTranslations()['en_US']->getSlug());
        $this->assertSame('English Meta Description', $requestModel->getTranslations()['en_US']->getMetaDescription());
        $this->assertSame('English Meta Keywords', $requestModel->getTranslations()['en_US']->getMetaKeywords());
        $this->assertSame('en_US', $requestModel->getTranslations()['en_US']->getLocale());

        $this->assertSame('German Name', $requestModel->getTranslations()['de_DE']->getName());
        $this->assertSame('German Description', $requestModel->getTranslations()['de_DE']->getDescription());
        $this->assertSame('German Short Description', $requestModel->getTranslations()['de_DE']->getShortDescription());
        $this->assertSame('German Slug', $requestModel->getTranslations()['de_DE']->getSlug());
        $this->assertSame('German Meta Description', $requestModel->getTranslations()['de_DE']->getMetaDescription());
        $this->assertSame('German Meta Keywords', $requestModel->getTranslations()['de_DE']->getMetaKeywords());
        $this->assertSame('de_DE', $requestModel->getTranslations()['de_DE']->getLocale());
    }

    public function testSerialization()
    {
        $collector = $this->prepareDataCollector();

        $mapper = new Mapper();
        $requestModel = $mapper->mapRequestModel($collector);

        $serializer = SerializerBuilder::create()->build();
        $json = $serializer->serialize($requestModel, 'json');

        $this->assertSame(
            '{"code":"123456","enabled":true,"mainTaxon":"testMainTaxon","channels":["unit_TEST"],"translations":{"en_US":{"name":"English Name","slug":"English Slug","description":"English Description","shortDescription":"English Short Description","metaKeywords":"English Meta Keywords","metaDescription":"English Meta Description"},"de_DE":{"name":"German Name","slug":"German Slug","description":"German Description","shortDescription":"German Short Description","metaKeywords":"German Meta Keywords","metaDescription":"German Meta Description"}}}',
            $json
        );
    }

    /**
     * @return DataCollectorInterface
     */
    private function prepareDataCollector()
    {
        // Add base attributes
        $collector = new DataCollector();
        $collector->addItem('id', '123456');
        $collector->addItem('mainTaxon', 'testMainTaxon');
        $collector->addItem('channels', ['unit_TEST' => 'unit_TEST']);

        // Add translated fields
        $collector->addItem('name', 'English Name', 'en_US');
        $collector->addItem('name', 'German Name', 'de_DE');

        $collector->addItem('description', 'English Description', 'en_US');
        $collector->addItem('description', 'German Description', 'de_DE');

        $collector->addItem('shortDescription', 'English Short Description', 'en_US');
        $collector->addItem('shortDescription', 'German Short Description', 'de_DE');

        $collector->addItem('slug', 'English Slug', 'en_US');
        $collector->addItem('slug', 'German Slug', 'de_DE');

        $collector->addItem('metaKeywords', 'English Meta Keywords', 'en_US');
        $collector->addItem('metaKeywords', 'German Meta Keywords', 'de_DE');

        $collector->addItem('metaDescription', 'English Meta Description', 'en_US');
        $collector->addItem('metaDescription', 'German Meta Description', 'de_DE');

        return $collector;
    }
}
